@@ -1,5 +1,5 @@
 package FIAS::SQL;
-$FIAS::SQL::VERSION = '0.04';
+$FIAS::SQL::VERSION = '0.05';
 # ABSTRACT: Модуль для минимальной работы с данными из базы ФИАC https://fias.nalog.ru/FiasInfo.aspx
 
 use strict;
@@ -40,6 +40,7 @@ Readonly our $LEVELS => {
    premises                  => '9'
 };
 
+
 sub new {
     my ( $class, %params ) = @_;
 
@@ -460,7 +461,6 @@ sub _get_quoted_text {
 
     return $text;
 }
-
 1;
 
 __END__
@@ -468,6 +468,7 @@ __END__
 =pod
 
 =encoding utf8
+=head1 DESCRIPTION Модуль для минимальной работы с данными из базы ФИАC https://fias.nalog.ru/FiasInfo.aspx
 =head1 NAME
 FIAS::SQL
 =head1 SYNOPSIS
@@ -478,7 +479,7 @@ FIAS::SQL - Модуль для минимальной работы с данн
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
     # Создание объекта, подключение к базе
     my  $fias = FIAS::SQL->new(
@@ -512,7 +513,11 @@ version 0.04
     # Получение всех помещений находящихся в строении с houseid '000012ba-2754-425c-ba4a-4c35d0771045'
     my $rooms =  $fias->get_rooms_of_address_objects( '000012ba-2754-425c-ba4a-4c35d0771045' );
 
-=head2 new
+=head2 методы модуля
+
+=over
+
+=item B<new>
     Создание объекта
 
     %params
@@ -526,12 +531,14 @@ version 0.04
                 mysql_enable_utf8 => 1
             }
 
-=head2 load_files
+=item B<load_files>
     Метод для загрузки dbf файлов в базу
-        $directory -- папка с DBF файлами
 
-=head2 get_address_objects
+    $directory -- папка с DBF файлами
+
+=item B<get_address_objects>
     Получение адресных объектов по уровню и родителю
+
     %params
         parentguid -- id родительского объекта
         aolevel    -- уровень получаемых объектов
@@ -560,17 +567,23 @@ version 0.04
     offname  --  Официальное наименование
     shortname -- Краткое наименование типа объекта
 
-=head2 get_sublevels_for_objects
+=item B<get_sublevels_for_objects>
     Получение списка уровней дочерних адресных объектов по id родителя
-        parentguid -- id родительского объекта
+
+    parentguid -- id родительского объекта
+
     Функция возвращает arrayref уровней
 
-=head2 get_data_for_object_by_aoguid
+=item B<get_data_for_object_by_aoguid>
     Получение данных адресного объекта по id
-        aoguid -- id  объекта
+
+    aoguid -- id  объекта
+
     Функция возвращает hashref c данными адресного объекта
 
-=head2 get_houses_of_address_objects
+=item B<get_houses_of_address_objects>
+    Функция возвращает список домов для адресного объекта
+
     Функция принимает на вход
         $aoguid -- родительский объект для всех домов.
     Функция возвращает  массив из hashrefs квартир в формате
@@ -588,12 +601,16 @@ version 0.04
     postalcode -- Почтовый индекс
     TODO добавить join для hststat?
 
-=head2 get_data_for_house_by_houseguid
+=item B<get_data_for_house_by_houseguid>
     Получение данных дома по id
-        houseguid -- id  объекта
+
+    houseguid -- id  дома
+
     Функция возвращает hashref c данными дома
 
-=head2 get_rooms_of_address_objects
+=item B<get_rooms_of_address_objects>
+    Функция возвращает список квартир для дома
+
     Функция принимает на вход
         $houseguid -- уникальный id дома
 
@@ -615,14 +632,17 @@ version 0.04
     roomnumber -- Номер комнаты или помещения
     roomtype   -- тип комнаты ( из справочника roomtype )
 
-=head2 get_data_for_room_by_roomguid
+=item B<get_data_for_room_by_roomguid>
     Получение данных квартиры по id
-        roomguid -- id  квартиры
+
+    roomguid -- id  квартиры
+
     Функция возвращает hashref c данными квартиры
 
-=head2 get_parent_record_chain_by_aoguid
+=item <get_parent_record_chain_by_aoguid>
     Получение цепочки элементов до верхнего уровня по aoguid
-        aoguid -- id нижнего элемента
+
+    aoguid -- id нижнего элемента
     Функция возвращает arrayref c данными записей
 [
     {
@@ -643,9 +663,11 @@ version 0.04
     }
 ]
 
-=head2 get_parent_record_chain_by_houseguid
-    Получение цепочки элементов до верхнего уровня по aoguid
-        houseguid -- id дома
+=item B<get_parent_record_chain_by_houseguid>
+    Получение цепочки элементов до верхнего уровня по houseguid
+
+    houseguid -- id дома
+
     Функция возвращает arrayref c данными записей
 [
     {
@@ -666,9 +688,11 @@ version 0.04
     }
 ]
 
-=head2 get_parent_record_chain_by_roomguid
-    Получение цепочки элементов до верхнего уровня по aoguid
-        roomguid -- id помещения
+=item B<get_parent_record_chain_by_roomguid>
+    Получение цепочки элементов до верхнего уровня по  roomguid
+
+    roomguid -- id помещения
+
     Функция возвращает arrayref c данными записей
 [
     {
@@ -693,53 +717,63 @@ version 0.04
     }
 ]
 
-=head2 _check_record_actuality
+=item B<_check_record_actuality>
     Проверка записи из DBF на актуальность
-        $record -- запись взятая из DBF,
 
-        возвращаем 1(неактуально) или 0(актуально)
+    $record -- запись взятая из DBF
 
-=head2 _get_table_fields
-    Функция для получения необходимых полей для записи в таблицы, значения полей берём из %table_config
-        $sql_table_name -- имя таблицы из DBF полученное обрезанием номера региона и расширения
-        HOUSE89.DBF превращается в HOUSE
-        $dbf_table -- объект XBase для получения полей из файлов не упомянутых в $table_config
+    возвращаем 1(неактуально) или 0(актуально)
 
-=head2 _create_table
+=item B<_get_table_fields>
+    Функция для получения необходимых полей для записи в таблицы.
+
+    значения полей берём из %table_config
+    $sql_table_name -- имя таблицы из DBF полученное обрезанием номера региона и расширения
+    HOUSE89.DBF превращается в HOUSE
+    $dbf_table -- объект XBase для получения полей из файлов упомянутых в $table_config
+
+=item B<_create_table>
     собираем комманду 'CREATE TABLE' для создания таблицы в базе
-        $sql_table_name -- имя таблицы из DBF полученное обрезанием номера региона и расширения
-        HOUSE89.DBF превращается в HOUSE
-        $dbf_table -- объект XBase для получения параметров полей в таблице
+
+    $sql_table_name -- имя таблицы из DBF полученное обрезанием номера региона и расширения
+    HOUSE89.DBF превращается в HOUSE
+    $dbf_table -- объект XBase для получения параметров полей в таблице
+
     Для каждой таблицы получаем на выходе SQL комманду 'CREATE TABLE ...'
 
-=head2 _convert_data
+=item B<_convert_data>
     конвертируем данные полученные из DBF в соответствующие данные для SQL
-        $record         -- запись
-        $dbf_table      -- объект XBase для получения данных поля DBF файла
-        $sql_table_name -- имя таблицы из DBF полученное обрезанием номера региона и расширения
-        HOUSE89.DBF превращается в HOUSE
+
+    $record         -- запись
+    $dbf_table      -- объект XBase для получения данных поля DBF файла
+    $sql_table_name -- имя таблицы из DBF полученное обрезанием номера региона и расширения
+    HOUSE89.DBF превращается в HOUSE
 
     На выходе получаем данные DBF удовлетворяющие стандарту SQL перечисленные через запятую
 
-=head2 _get_formatted_date
+=item B<_get_formatted_date>
     Получаем дату для SQL из даты для DBF
-        $date -- слитная дата из 8 цифр
+
+    $date -- слитная дата из 8 цифр
 
     Возвращаем дату разделённую дефисами для нормального помещения в SQL
 
-=head2 _get_quoted_text
+=item B<_get_quoted_text>
     Экранируем и декодируем полученный текст из DBF
+
         $text -- текст из DBF в cp866
 
     Возращаем удобоваримый и читаемый текст
 
+=back
+
 =head1 AUTHOR
 
 Daniil Popov <popov.daniil@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Daniil Popov.
+This software is copyright (c) 2017-2018 by Daniil Popov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
